%% Clear/close all
clear all; bdclose all;

%% Expcode setup
fprintf('\n### EXPCODE SETUP ###\n');
obj=expcodeconf_node06_demo12_test;
obj.init;
obj.setup;

%% expcode actualize
fprintf('\n### EXPCODE ACTUALIZE ###\n');
obj.actualize(-1);

%% expcode simulate
fprintf('\n### EXPCODE SIMULATION ###\n');
%obj.sim;
sim(obj.mainslxname);

%% wrappers build
fprintf('\n### CODE GENERATION ###\n');
obj.build; 

%% MARTe2 cfg file autogeneration
fprintf('\n### MARTE2 CFG FILE GENERATION ###\n');
cd nodes/marte2cfg/2threads/
algo_demo1and2_create_marte2_cfg;
cd ../../..

%% Transfer gencode and cfg to the realtime machine
fprintf('\n### FILE TRANSFER TO NODE06 ###\n');
%cd(fileparts(mfilename('fullpath'))); % this goes into /tmp/Editor on scd.epfl.ch
if isequal(SCDDSdemo.getsite(),'EPFL')
  system('scp nodes/marte2cfg/2threads/algo_demo1and2_2threads.cfg    tcv_oper@tcvrt17.crpp.tcv:~/martecfgs/tests');
  system('scp gencodes/CodeGenFolder-1/SCDwrap_demo1.so      tcv_oper@tcvrt17.crpp.tcv:~/martecfgs/tests');
  system('scp gencodes/CodeGenFolder-1/SCDwrap_demo2.so      tcv_oper@tcvrt17.crpp.tcv:~/martecfgs/tests');
elseif isequal(SCDDSdemo.getsite(),'PSFC')
  system('cp nodes/marte2cfg/2threads/algo_demo1and2_2threads.cfg    ~/MARTe2/MARTe2-examples/Configurations');
  system('cp gencodes/CodeGenFolder-1/SCDwrap_demo1.so      ~/MARTe2/MARTe2-examples');
  system('cp gencodes/CodeGenFolder-1/SCDwrap_demo2.so      ~/MARTe2/MARTe2-examples');
end

%% MARTe2 run via scdstarter

switch SCDDSdemo.getsite()
    case 'EPFL'
    fprintf('\n### MARTE2 RUN ON NODE06 (follow it on node06 logs of scd server) ###\n');
    system('echo -n "Class = Message Destination = ShotStarter Function = INIT" | nc tcvrt17.crpp.tcv 24681');
    case 'PSFC'
            fprintf('\n### MARTE2 RUN ON LOCALHOST ###\n');
       system('export MARTe2_Components_DIR=~/MARTe2/MARTe2-components; source /etc/profile.d/mdsplus.sh; cd ~/MARTe2/MARTe2-examples; ./runcfs.sh'); 
end


% poor man way of waiting MARTe2 job done
% MARTe2 is launched with a timeout of 10 seconds
% fprintf('\n### PAUSING 15 seconds ###\n');
% pause(15); 

%% MARTe2 output retrieval
fprintf('\n### MARTE2 DATA RETRIEVAL FROM MDSPLUS ###\n');
switch SCDDSdemo.getsite()
    case 'EPFL'
        mdsconnect('scd');
    case 'PSFC'
        mdsconnect('alcdaq6.psfc.mit.edu');
end

marteshot=mdsopen('scdds',0);

demo1signal1marte2=tdi('demo1.outputs.demo1.signal1');
demo1signal2marte2=tdi('demo1.outputs.demo1.signal2');
demo1signal3marte2=tdi('demo1.outputs.demo1.signal3');
demo1signal4marte2=tdi('demo1.outputs.demo1.signal4');
demo2signal1marte2=tdi('demo2.outputs.demo2.signal1');
demo2signal2marte2=tdi('demo2.outputs.demo2.signal2');
demo2signal3marte2=tdi('demo2.outputs.demo2.signal3');
demo2signal4marte2=tdi('demo2.outputs.demo2.signal4');

demo1threadcycletime  =tdi('demo1.system.ch01');
demo1simulinkreadtime =tdi('demo1.system.ch02');
demo1simulinkexectime =tdi('demo1.system.ch03');
demo1simulinkwritetime=tdi('demo1.system.ch04');

demo2threadcycletime  =tdi('demo2.system.ch01');
demo2simulinkreadtime =tdi('demo2.system.ch02');
demo2simulinkexectime =tdi('demo2.system.ch03');
demo2simulinkwritetime=tdi('demo2.system.ch04');

%% Plot combined simulation / realtime ouput signals
fprintf('\n### SIMULINK SIM / MARTE2 EXEC COMBINED PLOT ###\n');
figure(1);
clf
hold on

%simline='k--';
simline='k+';

plot(demo1simout.demo1.signal1,simline);
plot(demo1simout.demo1.signal2,simline);

plot(demo1simout.demo1.signal4,simline);

plot(demo2simout.demo2.signal1,simline);
plot(demo2simout.demo2.signal2,simline);

plot(demo2simout.demo2.signal4,simline);

%marteline='r-.';
marteline='ro';

plot(demo1signal1marte2,marteline);
plot(demo1signal2marte2,marteline);

plot(demo1signal4marte2,marteline);

plot(demo2signal1marte2,marteline);
plot(demo2signal2marte2,marteline);

plot(demo2signal4marte2,marteline);

xlim([0 3]);
xlabel('time [s]');
grid on

title('black cross: Simulink simulation, red circles MARTe2 run')

%% Plot timings
figure(2)

plot(demo1threadcycletime,'k');
hold on
plot(demo2threadcycletime,'r');

plot(demo1simulinkreadtime,'g');
plot(demo1simulinkexectime,'g');
plot(demo1simulinkwritetime,'g');
plot(demo2simulinkreadtime,'m');
plot(demo2simulinkexectime,'m');
plot(demo2simulinkwritetime,'m');

grid on
ylabel('[us]');
xlabel('time [s]');
title('MARTe2 timings');
ylim([800 1200]);

title('k: T1 cyclet, r: T2 cyclet, g: demo1 execs, m: demo2 execs');
